@@ -95,7 +95,7 @@ file_name_home_directory (void)
  * 	return f && f[0] && (f[0] == '/');
  */
 int
-file_name_is_absolute (t_uchar * f)
+file_name_is_absolute (const t_uchar * f)
 {
   return f && f[0] && (f[0] == '/');
 }
@@ -117,7 +117,7 @@ file_name_is_absolute (t_uchar * f)
  *
  */
 t_uchar *
-file_name_tilde_expand (alloc_limits limits, t_uchar * fname)
+file_name_tilde_expand (alloc_limits limits, const t_uchar * fname)
 {
   if (fname[0] != '~')
     return str_save (limits, fname);
@@ -139,7 +139,7 @@ file_name_tilde_expand (alloc_limits limits, t_uchar * fname)
 	}
       else
 	{
-	  t_uchar * pos;
+	  const t_uchar * pos;
 	  pos = fname + 2;
 	  while (*pos == '/')
 	    {
@@ -161,7 +161,7 @@ file_name_tilde_expand (alloc_limits limits, t_uchar * fname)
     }
   else
     {
-      t_uchar * uname_end;
+      const t_uchar * uname_end;
       int uname_len;
       t_uchar * uname;
       struct passwd * pwent;
@@ -235,7 +235,7 @@ file_name_tilde_expand (alloc_limits limits, t_uchar * fname)
  * If allocation fails (but does not call `panic') this function returns 0.
  */
 t_uchar *
-file_name_tail (alloc_limits limits, t_uchar * fname)
+file_name_tail (alloc_limits limits, const t_uchar * fname)
 {
   t_uchar * s;
 
@@ -253,7 +253,7 @@ file_name_tail (alloc_limits limits, t_uchar * fname)
  * 0			=> 	0
  */
 t_uchar *
-file_name_head (alloc_limits limits, char * fname)
+file_name_head (alloc_limits limits, const char * fname)
 {
   t_uchar * slash;
 
@@ -283,7 +283,7 @@ file_name_head (alloc_limits limits, char * fname)
  * 0			=> 	0
  */
 t_uchar *
-file_name_sans_head (alloc_limits limits, char * fname)
+file_name_sans_head (alloc_limits limits, const char * fname)
 {
   t_uchar * slash;
 
@@ -320,7 +320,7 @@ file_name_sans_head (alloc_limits limits, char * fname)
  * If allocation fails (but does not call `panic') this function returns 0.
  */
 t_uchar *
-file_name_as_directory (alloc_limits limits, t_uchar * f)
+file_name_as_directory (alloc_limits limits, const t_uchar * f)
 {
   int len;
   int already_is;
@@ -363,7 +363,7 @@ file_name_as_directory (alloc_limits limits, t_uchar * f)
  * If allocation fails (but does not call `panic') this function returns 0.
  */
 t_uchar * 
-file_name_from_directory (alloc_limits limits, t_uchar * f)
+file_name_from_directory (alloc_limits limits, const t_uchar * f)
 {
   t_uchar * answer;
   int len;
@@ -401,7 +401,7 @@ file_name_from_directory (alloc_limits limits, t_uchar * f)
  * If allocation fails (but does not call `panic') this function returns 0.
  */
 t_uchar *
-file_name_directory (alloc_limits limits, t_uchar * f)
+file_name_directory (alloc_limits limits, const t_uchar * f)
 {
   int len;
   int already_is;
@@ -457,7 +457,7 @@ file_name_directory (alloc_limits limits, t_uchar * f)
  * 
  */
 t_uchar *
-file_name_directory_file (alloc_limits limits, t_uchar * f)
+file_name_directory_file (alloc_limits limits, const t_uchar * f)
 {
   t_uchar * intermediate;
   t_uchar * answer;
@@ -492,7 +492,7 @@ file_name_directory_file (alloc_limits limits, t_uchar * f)
  * 
  */
 int
-file_name_is_path_prefix (t_uchar * maybe_prefix, t_uchar * path)
+file_name_is_path_prefix (const t_uchar * maybe_prefix, const t_uchar * path)
 {
   int len;
 
@@ -534,8 +534,8 @@ file_name_is_path_prefix (t_uchar * maybe_prefix, t_uchar * path)
  */
 t_uchar *
 file_name_in_vicinity (alloc_limits limits,
-		       t_uchar * dir,
-		       t_uchar * name)
+		       const t_uchar * dir,
+		       const t_uchar * name)
 {
   int dl;
   int nl;
@@ -600,7 +600,7 @@ file_name_in_vicinity (alloc_limits limits,
  * If allocation fails (but does not call `panic') this function returns 0.
  */
 t_uchar **
-path_parse (alloc_limits limits, t_uchar * path)
+path_parse (alloc_limits limits, const t_uchar * path)
 {
   t_converter answer;
   t_uchar ** loc;
@@ -631,7 +631,7 @@ path_parse (alloc_limits limits, t_uchar * path)
 	}
       else
 	{
-	  t_uchar * end;
+	  const t_uchar * end;
 
 	  end = str_chr_index (path, ':');
 	  if (!end)
@@ -679,8 +679,8 @@ free_path (alloc_limits limits, t_uchar ** path)
 
 /*(c path_find_executable)
  * t_uchar * path_find_executable (alloc_limits limits, 
- *				   t_uchar ** path,
- *				   t_uchar * tail);
+ *				   const t_uchar ** path,
+ *				   const t_uchar * tail);
  * 
  * Search on `path' for a file named `tail' that is executable by 
  * this process.  Returns a newly allocated copy of the name of such a file 
@@ -696,8 +696,8 @@ free_path (alloc_limits limits, t_uchar ** path)
  */
 t_uchar *
 path_find_executable (alloc_limits limits,
-		      t_uchar ** path,
-		      t_uchar * tail)
+		      const t_uchar ** path,
+		      const t_uchar * tail)
 {
   int x;
   t_uchar * answer;
