@@ -270,7 +270,7 @@ vfdbuf_buffer_fd (int * errn, int fd, long bufsize, int flags, int buffer_flags)
 
       if (bufs.vfd[fd].flags != flags)
 	{
-	  *errn = EINVAL;
+	  if (errn) *errn = EINVAL;
 	  return -1;
 	}
 
@@ -378,7 +378,7 @@ vfdbuf_set_buffer (int * errn,
     {
       /* not buffered */
     invalid:
-      *errn = EINVAL;
+      if (errn) *errn = EINVAL;
       return -1;
     }
 
@@ -466,7 +466,7 @@ vfdbuf_set_dont_flush (int * errn, int fd, int setting)
 {
   if (!vfdbuf_is_buffered (fd))
     {
-      *errn = EINVAL;
+      if (errn) *errn = EINVAL;
       return -1;
     }
 
@@ -489,7 +489,7 @@ vfdbuf_is_dont_flush (int * errn, int fd)
 {
   if (!vfdbuf_is_buffered (fd))
     {
-      *errn = EINVAL;
+      if (errn) *errn = EINVAL;
       return -1;
     }
 
@@ -522,7 +522,7 @@ vfdbuf_set_auto_shift (int * errn, int fd, int setting)
 {
   if (!vfdbuf_is_buffered (fd))
     {
-      *errn = EINVAL;
+      if (errn) *errn = EINVAL;
       return -1;
     }
 
@@ -545,7 +545,7 @@ vfdbuf_is_auto_shift (int * errn, int fd)
 {
   if (!vfdbuf_is_buffered (fd))
     {
-      *errn = EINVAL;
+      if (errn) *errn = EINVAL;
       return -1;
     }
 
@@ -581,7 +581,7 @@ sync_offset (int * errn, int fd)
       if (got != bufs.vfd[fd].buffer_offset)
 	{
 	  if (got >= 0)
-	    *errn = EIO;
+	    if (errn) *errn = EIO;
 	  return -1;
 	}
       bufs.vfd[fd].fd_offset = bufs.vfd[fd].buffer_offset;
@@ -630,7 +630,7 @@ vfdbuf_getbuf (int * errn,
 {
   if (!vfdbuf_is_buffered (fd))
     {
-      *errn = EINVAL;
+      if (errn) *errn = EINVAL;
       return -1;
     }
 
@@ -693,7 +693,7 @@ vfdbuf_takebuf (int * errn,
 {
   if (!vfdbuf_is_buffered (fd))
     {
-      *errn = EINVAL;
+      if (errn) *errn = EINVAL;
       return -1;
     }
 
@@ -840,7 +840,7 @@ vfdbuf_advance (int * errn, int fd, long amt)
 
   if (!vfdbuf_is_buffered (fd))
     {
-      *errn = EINVAL;
+      if (errn) *errn = EINVAL;
       return -1;
     }
 
@@ -891,7 +891,7 @@ vfdbuf_flush (int * errn, int fd)
 
   if (!vfdbuf_is_buffered (fd))
     {
-      *errn = EINVAL;
+      if (errn) *errn = EINVAL;
       return -1;
     }
 
@@ -965,7 +965,7 @@ vfdbuf_return (int * errn, int fd, t_uchar * str, long len)
 
   if (!vfdbuf_is_buffered (fd))
     {
-      *errn = EINVAL;
+      if (errn) *errn = EINVAL;
       return -1;
     }
 
@@ -1054,7 +1054,7 @@ vfdbuf_more (int * errn,
   
   if (!vfdbuf_is_buffered (fd))
     {
-      *errn = EINVAL;
+      if (errn) *errn = EINVAL;
       return -1;
     }
 
@@ -1106,7 +1106,7 @@ vfdbuf_more (int * errn,
 
 	if (went_to != offset)
 	  {
-	    *errn = EIO;
+	    if (errn) *errn = EIO;
 	    return -1;
 	  }
 	    
@@ -1156,7 +1156,7 @@ vfdbuf_is_eof (int * errn, int fd)
 {
   if (!vfdbuf_is_buffered (fd))
     {
-      *errn = EINVAL;
+      if (errn) *errn = EINVAL;
       return -1;
     }
 
@@ -1176,7 +1176,7 @@ vfdbuf_clear_eof (int * errn, int fd)
 {
   if (!vfdbuf_is_buffered (fd))
     {
-      *errn = EINVAL;
+      if (errn) *errn = EINVAL;
       return -1;
     }
 
@@ -1193,35 +1193,35 @@ vfdbuf_clear_eof (int * errn, int fd)
 
 
 int
-vfdbuf_access (int * errn, char * path, int mode, void * closure)
+vfdbuf_access (int * errn, const char * path, int mode, void * closure)
 {
   return vu_sys_access (errn, path, mode, closure);
 }
 
 
 int
-vfdbuf_chdir (int * errn, char * path, void * closure)
+vfdbuf_chdir (int * errn, const char * path, void * closure)
 {
   return vu_sys_chdir (errn, path, closure);
 }
 
 
 int
-vfdbuf_chmod (int * errn, char * path, int mode, void * closure)
+vfdbuf_chmod (int * errn, const char * path, int mode, void * closure)
 {
   return vu_sys_chmod (errn, path, mode, closure);
 }
 
 
 int
-vfdbuf_chown (int * errn, char * path, int owner, int group, void * closure)
+vfdbuf_chown (int * errn, const char * path, int owner, int group, void * closure)
 {
   return vu_sys_chown (errn, path, owner, group, closure);
 }
 
 
 int
-vfdbuf_chroot (int * errn, char * path, void * closure)
+vfdbuf_chroot (int * errn, const char * path, void * closure)
 {
   return vu_sys_chroot (errn, path, closure);
 }
@@ -1263,35 +1263,35 @@ vfdbuf_fstat (int * errn, int fd, struct stat * buf, void * closure)
 
 
 int
-vfdbuf_link (int * errn, char * from, char * to, void * closure)
+vfdbuf_link (int * errn, const char * from, const char * to, void * closure)
 {
   return vu_sys_link (errn, from, to, closure);
 }
 
 
 int
-vfdbuf_lstat (int * errn, char * path, struct stat * buf, void * closure)
+vfdbuf_lstat (int * errn, const char * path, struct stat * buf, void * closure)
 {
   return vu_sys_lstat (errn, path, buf, closure);
 }
 
 
 int
-vfdbuf_mkdir (int * errn, char * path, int mode, void * closure)
+vfdbuf_mkdir (int * errn, const char * path, int mode, void * closure)
 {
   return vu_sys_mkdir (errn, path, mode, closure);
 }
 
 
 int
-vfdbuf_open (int * errn, char * path, int flags, int mode, void * closure)
+vfdbuf_open (int * errn, const char * path, int flags, int mode, void * closure)
 {
   return vu_sys_open (errn, path, flags, mode, closure);
 }
 
 
 int
-vfdbuf_opendir (int * errn, DIR ** retv,  char * path, void * closure)
+vfdbuf_opendir (int * errn, DIR ** retv,  const char * path, void * closure)
 {
   return vu_sys_opendir (errn, retv,  path, closure);
 }
@@ -1305,56 +1305,56 @@ vfdbuf_readdir (int * errn, struct alloc_limits * limits, char ** file_ret, DIR
 
 
 int
-vfdbuf_readlink (int * errn, char * path, char * buf, int bufsize, void * closure)
+vfdbuf_readlink (int * errn, const char * path, char * buf, int bufsize, void * closure)
 {
   return vu_sys_readlink (errn, path, buf, bufsize, closure);
 }
 
 
 int
-vfdbuf_rename (int * errn, char * from, char * to, void * closure)
+vfdbuf_rename (int * errn, const char * from, const char * to, void * closure)
 {
   return vu_sys_rename (errn, from, to, closure);
 }
 
 
 int
-vfdbuf_rmdir (int * errn, char * path, void * closure)
+vfdbuf_rmdir (int * errn, const char * path, void * closure)
 {
   return vu_sys_rmdir (errn, path, closure);
 }
 
 
 int
-vfdbuf_stat  (int * errn, char * path, struct stat * buf, void * closure)
+vfdbuf_stat  (int * errn, const char * path, struct stat * buf, void * closure)
 {
   return vu_sys_stat (errn, path, buf, closure);
 }
 
 
 int
-vfdbuf_symlink (int * errn, char * from, char * to, void * closure)
+vfdbuf_symlink (int * errn, const char * from, const char * to, void * closure)
 {
   return vu_sys_symlink (errn, from, to, closure);
 }
 
 
 int
-vfdbuf_truncate (int * errn, char * path, off_t where, void * closure)
+vfdbuf_truncate (int * errn, const char * path, off_t where, void * closure)
 {
   return vu_sys_truncate (errn, path, where, closure);
 }
 
 
 int
-vfdbuf_unlink (int * errn, char * path, void * closure)
+vfdbuf_unlink (int * errn, const char * path, void * closure)
 {
   return vu_sys_unlink (errn, path, closure);
 }
 
 
 int
-vfdbuf_utime (int * errn, char * path, struct utimbuf * times, void * closure)
+vfdbuf_utime (int * errn, const char * path, struct utimbuf * times, void * closure)
 {
   return vu_sys_utime (errn, path, times, closure);
 }
@@ -1462,7 +1462,7 @@ vfdbuf_fsync (int * errn, int fd, void * closure)
     {
       if (bufs.vfd[fd].dont_flush)
 	{
-	  *errn = EINVAL;
+	  if (errn) *errn = EINVAL;
 	  return -1;
 	}
       if (vfdbuf_flush (errn, fd) < 0)
@@ -1650,7 +1650,7 @@ vfdbuf_read (int * errn, int fd, char * buf, size_t count, void * closure)
 
 
 ssize_t
-vfdbuf_write (int * errn, int fd, char * buf, size_t count, void * closure)
+vfdbuf_write (int * errn, int fd, const char * buf, size_t count, void * closure)
 {
   ssize_t orig_count;
   ssize_t avail;
@@ -1708,7 +1708,7 @@ vfdbuf_write (int * errn, int fd, char * buf, size_t count, void * closure)
 	    }
 	  else
 	    {
-	      *errn = errn2;
+	      if (errn) *errn = errn2;
 	      return -1;
 	    }
 	}
@@ -1775,7 +1775,7 @@ vfdbuf_lseek (int * errn, int fd, off_t offset, int whence, void * closure)
 	      else
 		{
 		espipe_error:
-		  *errn = ESPIPE;
+		  if (errn) *errn = ESPIPE;
 		  return -1;
 		}
 	    }
@@ -1812,7 +1812,7 @@ vfdbuf_lseek (int * errn, int fd, off_t offset, int whence, void * closure)
   switch (whence)
     {
     default:
-      *errn = EINVAL;
+      if (errn) *errn = EINVAL;
       return -1;
       
     case SEEK_SET:
@@ -1846,7 +1846,7 @@ vfdbuf_lseek (int * errn, int fd, off_t offset, int whence, void * closure)
 	   */
 	  if (bufs.vfd[fd].dont_flush)
 	    {
-	      *errn = EINVAL;
+	      if (errn) *errn = EINVAL;
 	      return -1;
 	    }
 	  if (0 > vfdbuf_flush (errn, fd))
