@@ -33,7 +33,7 @@
 
 
 /* __STDC__ prototypes for static functions */
-static void apply_delta_callback (void * vfd, char * fmt, va_list ap);
+static void apply_delta_callback (void * vfd, const char * fmt, va_list ap);
 
 
 
@@ -263,7 +263,7 @@ arch_cmd_apply_delta (t_uchar * program_name, int argc, char * argv[])
 
 
 static void
-apply_delta_callback (void * vfd, char * fmt, va_list ap)
+apply_delta_callback (void * vfd, const char * fmt, va_list ap)
 {
   int fd;
 
