@@ -143,7 +143,7 @@ arch_cmd_help (t_uchar * program_name, int argc, char * argv[])
     safe_printfmt (1, "\n");
   }
 
-  safe_printfmt (1, "\nUse tla command -h for help on `command', or tla command -H for detailed help\n");
+  safe_printfmt (1, "\nUse tla command -h for help on `command', or tla command -H for detailed help.\n");
 
   return 0;
 }
