@@ -13,6 +13,7 @@
 #include "tla/libarch/my.h"
 #include "tla/libarch/libraries.h"
 #include "tla/libarch/namespace.h"
+#include "tla/libarch/cmdutils.h"
 #include "tla/libarch/cmd-library-log.h"
 
 
@@ -137,6 +138,8 @@ arch_cmd_library_log (t_uchar * program_name, int argc, char * argv[])
 
     revision = arch_parse_package_name (arch_ret_non_archive, 0, revspec);
 
+    arch_check_library_for_revision (archive, revision);
+
     answer = arch_library_log (archive, revision);
 
     if (answer)
