@@ -93,6 +93,7 @@
 #include "tla/libarch/cmd-id-tagging-defaults.h"
 #include "tla/libarch/cmd-id-tagging-method.h"
 #include "tla/libarch/cmd-tag.h"
+#include "tla/libarch/cmd-touch.h"
 #include "tla/libarch/cmd-tree-lint.h"
 #include "tla/libarch/cmd-tree-root.h"
 #include "tla/libarch/cmd-tree-version.h"
@@ -158,6 +159,7 @@ struct arch_command arch_commands[] =
   {"add-id", arch_cmd_add_id, arch_cmd_add_id_help, 0, 0},
   {"delete-id", arch_cmd_delete_id, arch_cmd_delete_id_help, 0, 0},
   {"move-id", arch_cmd_move_id, arch_cmd_move_id_help, 0, 0},
+  {"touch", arch_cmd_touch, arch_cmd_touch_help, 0, 0},
   {"rm", arch_cmd_rm, arch_cmd_rm_help, 0, 0},
   {"mv", arch_cmd_mv, arch_cmd_mv_help, 0, 0},
   {"explicit-default", arch_cmd_default_id, arch_cmd_default_id_help, 0, 0},
