@@ -102,14 +102,14 @@ static int
 category_exists (struct arch_archive *arch, t_uchar * package)
 {
   t_uchar * category = 0;
-  rel_table categories = 0;
+  rel_table categories = rel_table_nil;
   int x;
   
   category = arch_parse_package_name (arch_ret_category, 0, package);
   categories = arch_archive_categories (arch);
   for (x = 0; x < rel_n_records (categories); ++x)
     {
-      if (!str_cmp (category, categories[x][0]))
+      if (!str_cmp (category, rel_peek_str (categories, x, 0)))
       {
         lim_free (0, category);
         rel_free_table (categories);
@@ -125,8 +125,8 @@ package_exists (struct arch_archive * arch, t_uchar * package)
 {
   t_uchar * category = 0;
   t_uchar * branch = 0;
-  rel_table categories = 0;
-  rel_table branches = 0;
+  rel_table categories = rel_table_nil;
+  rel_table branches = rel_table_nil;
   int x;
   int found_it = 0;
 
@@ -136,7 +136,7 @@ package_exists (struct arch_archive * arch, t_uchar * package)
   categories = arch_archive_categories (arch);
   for (x = 0; x < rel_n_records (categories); ++x)
     {
-      if (!str_cmp (category, categories[x][0]))
+      if (!str_cmp (category, rel_peek_str (categories, x, 0)))
         break;
     }
 
@@ -146,7 +146,7 @@ package_exists (struct arch_archive * arch, t_uchar * package)
 
       for (x = 0; x < rel_n_records (branches); ++x)
         {
-          if (!str_cmp (branch, branches[x][0]))
+          if (!str_cmp (branch, rel_peek_str (branches, x, 0)))
             {
               found_it = 1;
               break;
@@ -166,7 +166,7 @@ version_exists (struct arch_archive * arch, t_uchar * version_spec)
 {
   t_uchar * branch = 0;
   t_uchar * version = 0;
-  rel_table versions = 0;
+  rel_table versions = rel_table_nil;
   int x;
   int found_it = 0;
 
@@ -176,7 +176,7 @@ version_exists (struct arch_archive * arch, t_uchar * version_spec)
 
   for (x = 0; x < rel_n_records (versions); ++x)
     {
-      if (!str_cmp (version, versions[x][0]))
+      if (!str_cmp (version, rel_peek_str (versions, x, 0)))
         {
           found_it = 1;
           break;
@@ -334,7 +334,7 @@ void
 arch_check_library_for_revision (t_uchar * archive,
                                  t_uchar * revision)
 {
-  t_uchar * loc = arch_library_find (0, archive, revision, 0);
+  t_uchar * loc = arch_library_find (rel_table_nil, archive, revision, 0);
   if (loc)
      {
    lim_free (0, loc);
@@ -459,5 +459,49 @@ arch_check_uri (t_uchar * uri)
   exit (2);
 }
 
+
+/**
+ * Check whether the revision exists, using local data first, before
+ * trying the archive
+ * archive: the archive containg the revision
+ * revision: the unqualified revision
+ */
+extern void
+arch_check_revision_local (t_uchar * archive,
+                           t_uchar * revision)
+{
+  struct arch_archive * arch = 0;
+  t_uchar * loc = arch_library_find (rel_table_nil, archive, revision, 0);
+  if (loc)
+    {
+      lim_free (0, loc);
+      return;
+    }
+  arch = arch_archive_connect (archive, 0);
+  arch_check_for (arch, arch_req_patch_level, revision);
+  arch_archive_close (arch);
+}
+
+
+/**
+ * Check the archive to make sure it's suitable for normal use, and not just
+ * for mirroring.
+ */
+extern void
+arch_check_arch (struct arch_archive * arch)
+{
+  if (str_cmp (arch->name, arch->official_name))
+    {
+      safe_printfmt (2, ("This archive can only be used as a mirror source or target, because it is\n"
+                         "registered with the wrong name.  To use it for other purposes, you should\n"
+                         "register it using the official name.\n"
+                         "  name: %s\n"
+                         "  official name: %s\n"
+                         "  location: %s\n"),
+                     arch->name, arch->official_name, arch->location);
+      exit (2);
+    }
+}
+
 /* tag: Aaron Bentley Tue Dec 23 10:46:00 2003 (cmdutils.c)
  */
