@@ -377,13 +377,15 @@ arch_library_add (int chatter_fd,
 
   if (library_ancestor)
     {
+      const int full_meta = arch_tree_has_meta_flag (library_ancestor);
+
       /* If the immediate ancestor exists in the same library,
        * then fill our tmp dir with a link-tree to that ancestor.
        * It will be patched for our target revision later.
        */
 
       arch_chatter (chatter_fd, "* found immediate ancestor revision in library (%s/%s)\n", ancestor_archive, ancestor_revision);
-      build_link_tree (library_ancestor, tmp_dir);
+      build_link_tree (library_ancestor, tmp_dir, full_meta);
     }
   else if (!fq_ancestor_rev || str_cmp (ancestor_archive, arch->name))
     {
@@ -414,6 +416,8 @@ arch_library_add (int chatter_fd,
     }
   else if (!sparse)
     {
+      const int full_meta = arch_tree_has_meta_flag (library_ancestor);
+
       /* There is an ancestor, it's in the same archive, it's not 
        * in the library, and we're not building a --sparse library.
        * So, recursively add the ancestor to the library and then
@@ -423,7 +427,7 @@ arch_library_add (int chatter_fd,
       arch_chatter (chatter_fd, "* recursively adding %s/%s to library\n", ancestor_archive, ancestor_revision);
       arch_library_add (chatter_fd, no_patch_noise, arch, ancestor_revision, opt_library, opt_same_dev_path, 0, escape_classes);
       library_ancestor = arch_library_find (rel_table_nil, ancestor_archive, ancestor_revision, 1);
-      build_link_tree (library_ancestor, tmp_dir);
+      build_link_tree (library_ancestor, tmp_dir, full_meta);
     }
   else
     {
@@ -494,13 +498,14 @@ arch_library_add (int chatter_fd,
        */
       if (anc_lib)
         {
-           arch_chatter (chatter_fd, "* found ancestor revision in library (%s/%s)\n", anc_arch, anc_rev);
-           arch_chatter (chatter_fd, "* patching for this revision (%s/%s)\n", ancestor_archive, revision);
-           build_link_tree (anc_lib, tmp_dir);
-           rel_reverse_table (revisions);
-           replay_status = arch_replay_list (chatter_fd, 1, tmp_dir, arch, revisions, 0, 0, escape_classes);
-           invariant (!replay_status);
-           lim_free (0, anc_lib);
+          const int full_meta = arch_tree_has_meta_flag (anc_lib);
+          arch_chatter (chatter_fd, "* found ancestor revision in library (%s/%s)\n", anc_arch, anc_rev);
+          arch_chatter (chatter_fd, "* patching for this revision (%s/%s)\n", ancestor_archive, revision);
+          build_link_tree (anc_lib, tmp_dir, full_meta);
+          rel_reverse_table (revisions);
+          replay_status = arch_replay_list (chatter_fd, 1, tmp_dir, arch, revisions, 0, 0, escape_classes);
+          invariant (!replay_status);
+          lim_free (0, anc_lib);
         }
       else
         {
