@@ -166,14 +166,14 @@ arch_prepare_for_tag (t_uchar ** cooked_log_ret, struct arch_archive * arch, t_u
   t_uchar * human_date = 0;
   t_uchar * from_version = 0;
   int out_fd;
-  rel_table merge_points = 0;
+  rel_table merge_points = rel_table_nil;
   t_uchar * fqrevision = 0;
   t_uchar * cooked_log = 0;
   t_uchar * changeset_dir_path = 0; /* allocated and returned */
   t_uchar * changeset_tail = 0;
   t_uchar * changeset_path = 0;
   struct arch_make_changeset_report make_report = {0, };
-  struct arch_changeset_report report = {0, };
+  struct arch_changeset_report report = {rel_table_nil, };
   int log_fd = -1;
   t_uchar * log_loc = 0;
   t_uchar * log_id = 0;
@@ -187,7 +187,7 @@ arch_prepare_for_tag (t_uchar ** cooked_log_ret, struct arch_archive * arch, t_u
 
   merge_points = arch_archive_merge_points (from_arch, from_revision, 0, 0, 1);
   fqrevision = arch_fully_qualify (arch->name, revision);
-  rel_add_records (&merge_points, rel_make_record ("!!!!!nothing-should-depend-on-this", fqrevision, 0), 0);
+  rel_add_records (&merge_points, rel_make_record_2_taking (rel_make_field_str ("!!!!!nothing-should-depend-on-this"), rel_make_field_str (fqrevision)), 0);
   rel_sort_table_by_field (0, merge_points, 1);
   rel_uniq_by_field (&merge_points, 1);
   arch_sort_table_by_name_field (0, merge_points, 1);
